@@ -6,11 +6,17 @@ from typing import Any, Optional
 import appdirs
 
 from ansys.fluent.core._version import __version__  # noqa: F401
-from ansys.fluent.core.launcher.launcher import launch_fluent  # noqa: F401
-from ansys.fluent.core.session import Session as Fluent  # noqa: F401
+from ansys.fluent.core.launcher.launcher import (  # noqa: F401
+    FluentVersion,
+    LaunchModes,
+    launch_fluent,
+    set_ansys_version,
+    set_fluent_path,
+)
+from ansys.fluent.core.session import _BaseSession as Fluent  # noqa: F401
 from ansys.fluent.core.utils.logging import LOG
 
-_VERSION_INFO = "Build date: July 07, 2022 12:02 UTC ShaID: c8b3222"
+_VERSION_INFO = "Build date: September 02, 2022 17:31 UTC ShaID: ed40716"
 """Global variable indicating the version of the PyFluent package - Empty by default"""
 
 _THIS_DIRNAME = os.path.dirname(__file__)
